# UI/UX Feedback

**ID:** Feedback-20260308-155507
**URL:** http://127.0.0.1:5858/
**Date:** 2026-03-08 15:55:31

## Selected Elements

- `{'selector': 'div.nav-section-header', 'parents': ['div#middle-section', 'nav#sidebar', 'div#sidebar-content', 'div.nav-section']}`

## Feedback

for the sidebar menu, I would like to hover to expend instead click

## Screenshot

![Screenshot](./page-screenshot.png)
